==> gorilla-notebook-0.4.0.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.notifications.js <==
goog.provide('pinkgorilla.notifications');
goog.require('cljs.core');
goog.require('re_frame.core');
pinkgorilla.notifications.notification_types = new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 5, [new cljs.core.Keyword(null,"primary","primary",817773892),null,new cljs.core.Keyword(null,"warning","warning",-1685650671),null,new cljs.core.Keyword(null,"danger","danger",-624338030),null,new cljs.core.Keyword(null,"success","success",1890645906),null,new cljs.core.Keyword(null,"info","info",-317069002),null], null), null);
pinkgorilla.notifications.notification = (function pinkgorilla$notifications$notification(var_args){
var G__11185 = arguments.length;
switch (G__11185) {
case 2:
return pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 1:
return pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$2 = (function (type,text){
if(cljs.core.truth_((pinkgorilla.notifications.notification_types.cljs$core$IFn$_invoke$arity$1 ? pinkgorilla.notifications.notification_types.cljs$core$IFn$_invoke$arity$1(type) : pinkgorilla.notifications.notification_types.call(null,type)))){
} else {
throw (new Error("Assert failed: (notification-types type)"));
}

return new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"id","id",-1388402092),cljs.core.random_uuid(),new cljs.core.Keyword(null,"type","type",1174270348),type,new cljs.core.Keyword(null,"text","text",-1790561697),text], null);
}));

(pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$1 = (function (text){
return pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"primary","primary",817773892),text);
}));

(pinkgorilla.notifications.notification.cljs$lang$maxFixedArity = 2);

pinkgorilla.notifications.add_notification = (function pinkgorilla$notifications$add_notification(n){
if(cljs.core.map_QMARK_(n)){
var G__11191 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"notification-add","notification-add",-85956164),n], null);
return (re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1(G__11191) : re_frame.core.dispatch.call(null,G__11191));
} else {
if(typeof n === 'string'){
var G__11192 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"notification-add","notification-add",-85956164),pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$1(n)], null);
return (re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1(G__11192) : re_frame.core.dispatch.call(null,G__11192));
} else {
return null;
}
}
});

//# sourceMappingURL=pinkgorilla.notifications.js.map

==> gorilla-notebook-0.4.2.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.notifications.js <==
goog.provide('pinkgorilla.notifications');
goog.require('cljs.core');
goog.require('re_frame.core');
pinkgorilla.notifications.notification_types = new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 5, [new cljs.core.Keyword(null,"primary","primary",817773892),null,new cljs.core.Keyword(null,"warning","warning",-1685650671),null,new cljs.core.Keyword(null,"danger","danger",-624338030),null,new cljs.core.Keyword(null,"success","success",1890645906),null,new cljs.core.Keyword(null,"info","info",-317069002),null], null), null);
pinkgorilla.notifications.notification = (function pinkgorilla$notifications$notification(var_args){
var G__40601 = arguments.length;
switch (G__40601) {
case 2:
return pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 1:
return pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$2 = (function (type,text){
if(cljs.core.truth_((pinkgorilla.notifications.notification_types.cljs$core$IFn$_invoke$arity$1 ? pinkgorilla.notifications.notification_types.cljs$core$IFn$_invoke$arity$1(type) : pinkgorilla.notifications.notification_types.call(null,type)))){
} else {
throw (new Error("Assert failed: (notification-types type)"));
}

return new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"id","id",-1388402092),cljs.core.random_uuid(),new cljs.core.Keyword(null,"type","type",1174270348),type,new cljs.core.Keyword(null,"text","text",-1790561697),text], null);
}));

(pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$1 = (function (text){
return pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"primary","primary",817773892),text);
}));

(pinkgorilla.notifications.notification.cljs$lang$maxFixedArity = 2);

pinkgorilla.notifications.add_notification = (function pinkgorilla$notifications$add_notification(n){
if(cljs.core.map_QMARK_(n)){
var G__40604 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"notification-add","notification-add",-85956164),n], null);
return (re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1(G__40604) : re_frame.core.dispatch.call(null,G__40604));
} else {
if(typeof n === 'string'){
var G__40605 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"notification-add","notification-add",-85956164),pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$1(n)], null);
return (re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1(G__40605) : re_frame.core.dispatch.call(null,G__40605));
} else {
return null;
}
}
});
goog.exportSymbol('pinkgorilla.notifications.add_notification', pinkgorilla.notifications.add_notification);

//# sourceMappingURL=pinkgorilla.notifications.js.map
